export declare const settingsMap: {
    [key: string]: {
        setting: string;
        units?: string;
        datatype: "string" | "integer" | "float" | "bool" | "bitfield" | "xbitfield" | "ip4" | "radiobuttons";
        dataFormat?: string;
        description: string;
        min?: number;
        max?: number;
    };
};
export declare const gcodeMap: {
    readonly gcode: {
        readonly G0: {
            readonly name: "Movement";
            readonly description: "The last movement command";
        };
        readonly G54: {
            readonly name: "WCS";
            readonly description: "Default Work Coordinate System";
        };
        readonly G17: {
            readonly name: "Plane";
            readonly description: "X Y (default)";
        };
        readonly G21: {
            readonly name: "Units";
            readonly description: "Current units";
        };
        readonly G28: {
            readonly name: "Predefined Position";
            readonly description: "Go to Predefined Position";
        };
        readonly G90: {
            readonly name: "Distance Mode";
            readonly description: "Absolute distance mode";
        };
        readonly G94: {
            readonly name: "Feed Rate Mode";
            readonly description: "Units per minute mode";
        };
        readonly G92: {
            readonly name: "";
            readonly description: "";
        };
        readonly G55: {
            readonly name: "";
            readonly description: "";
        };
        readonly G56: {
            readonly name: "";
            readonly description: "";
        };
        readonly G57: {
            readonly name: "";
            readonly description: "";
        };
        readonly G58: {
            readonly name: "";
            readonly description: "";
        };
        readonly G59: {
            readonly name: "";
            readonly description: "";
        };
        readonly "G59.1": {
            readonly name: "";
            readonly description: "";
        };
        readonly "G59.2": {
            readonly name: "";
            readonly description: "";
        };
        readonly "G59.3": {
            readonly name: "";
            readonly description: "";
        };
        readonly G30: {
            readonly name: "";
            readonly description: "";
        };
        readonly G5: {
            readonly name: "";
            readonly description: "";
        };
        readonly G7: {
            readonly name: "";
            readonly description: "";
        };
        readonly G8: {
            readonly name: "";
            readonly description: "";
        };
        readonly G43: {
            readonly name: "";
            readonly description: "";
        };
        readonly G49: {
            readonly name: "";
            readonly description: "";
        };
        readonly G50: {
            readonly name: "";
            readonly description: "";
        };
        readonly G51: {
            readonly name: "";
            readonly description: "";
        };
        readonly G73: {
            readonly name: "";
            readonly description: "";
        };
        readonly G81: {
            readonly name: "";
            readonly description: "";
        };
        readonly G82: {
            readonly name: "";
            readonly description: "";
        };
        readonly G83: {
            readonly name: "";
            readonly description: "";
        };
        readonly G85: {
            readonly name: "";
            readonly description: "";
        };
        readonly G86: {
            readonly name: "";
            readonly description: "";
        };
        readonly G89: {
            readonly name: "";
            readonly description: "";
        };
        readonly G96: {
            readonly name: "";
            readonly description: "";
        };
        readonly G97: {
            readonly name: "";
            readonly description: "";
        };
        readonly G98: {
            readonly name: "";
            readonly description: "";
        };
        readonly G99: {
            readonly name: "";
            readonly description: "";
        };
    };
    readonly mcode: {
        readonly M0: {
            readonly name: "Suspended";
            readonly description: "Machine is currently suspended";
        };
        readonly M5: {
            readonly name: "Spindle";
            readonly description: "Spindle stopped";
        };
        readonly M9: {
            readonly name: "Coolant";
            readonly description: "Coolant stopped";
        };
        readonly M1: {
            readonly name: "";
            readonly description: "";
        };
        readonly M50: {
            readonly name: "";
            readonly description: "";
        };
        readonly M51: {
            readonly name: "";
            readonly description: "";
        };
        readonly M53: {
            readonly name: "";
            readonly description: "";
        };
        readonly M56: {
            readonly name: "";
            readonly description: "";
        };
        readonly M60: {
            readonly name: "";
            readonly description: "";
        };
    };
    readonly tool: {
        readonly TLO: {
            readonly name: "Tool length offset";
            readonly description: "The distance the tool is offset from the current WCS";
        };
    };
};
export declare const errorMap: {
    [key: string]: {
        message: string;
        description: string;
    };
};
export declare const alarmMap: {
    [key: string]: {
        message: string;
        description: string;
    };
};
export declare const supportedVersions: readonly ["Grbl 1.1e", "Grbl 1.1f"];
export declare const buildOptionsMap: {
    readonly V: "Variable spindle enabled";
    readonly N: "Line numbers enabled";
    readonly M: "Mist coolant enabled";
    readonly C: "CoreXY enabled";
    readonly P: "Parking motion enabled";
    readonly Z: "Homing force origin enabled";
    readonly H: "Homing single axis enabled";
    readonly T: "Two limit switches on axis enabled";
    readonly A: "Allow feed rate overrides in probe cycles";
    readonly "*": "Restore all EEPROM disabled";
    readonly $: "Restore EEPROM $ settings disabled";
    readonly "#": "Restore EEPROM parameter data disabled";
    readonly I: "Build info write user string disabled";
    readonly E: "Force sync upon EEPROM write disabled";
    readonly W: "Force sync upon work coordinate offset change disabled";
    readonly L: "Homing init lock sets Grbl into an alarm state upon power up";
};
export declare const statusStateTypes: readonly ["Idle", "Run", "Hold", "Jog", "Alarm", "Door", "Check", "Home", "Sleep", "Tool"];
export declare type StatusStateType = typeof statusStateTypes[number];
export declare const subStateMessage: {
    readonly Door: {
        readonly 0: "Door closed. Ready to resume.";
        readonly 1: "Machine stopped. Door still ajar. Can't resume until closed.";
        readonly 2: "Door opened. Hold (or parking retract) in-progress. Reset will throw an alarm.";
        readonly 3: "Door closed and resuming. Restoring from park, if applicable. Reset will throw an alarm.";
    };
    readonly Hold: {
        readonly 0: "Hold complete. Ready to resume.";
        readonly 1: "Hold in-progress. Reset will throw an alarm.";
    };
};
export declare const statusMap: {
    readonly A: "accessories";
    readonly Bf: "buffer";
    readonly Buf: "buffer";
    readonly RX: "buffer";
    readonly FS: "realtimeFeed";
    readonly MPos: "machinePosition";
    readonly Ov: "override";
    readonly Lim: "pins";
    readonly Pn: "pins";
    readonly Pin: "pins";
    readonly WCO: "workcoordinateOffset";
    readonly WPos: "workPosition";
};
export declare const limitPinMap: {
    readonly 0: "limit-x";
    readonly 1: "limit-y";
    readonly 2: "limit-z";
    readonly 3: "limit-a";
    readonly 4: "limit-b";
    readonly 5: "limit-c";
};
export declare const controlPinMap: {
    readonly 0: "door";
    readonly 1: "hold";
    readonly 2: "soft-reset";
    readonly 3: "cycle-start";
};
export declare const grbl11PinMap: {
    readonly X: "limit-x";
    readonly Y: "limit-y";
    readonly Z: "limit-z";
    readonly A: "limit-a";
    readonly B: "limit-b";
    readonly C: "limit-c";
    readonly P: "probe";
    readonly D: "door";
    readonly H: "hold";
    readonly R: "soft-reset";
    readonly S: "cycle-start";
    readonly T: "program-stop";
    readonly E: "e-stop";
    readonly O: "probe-disconnected";
};
